/*
 * Copyright (c) 2022 Contributors to the Eclipse Foundation.
 * 
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *   Data In Motion - initial API and implementation 
 */
package org.eclipse.sensinact.model.core.provider;


import org.eclipse.emf.ecore.EAttribute;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EDataType;
import org.eclipse.emf.ecore.EEnum;
import org.eclipse.emf.ecore.EOperation;
import org.eclipse.emf.ecore.EReference;

import org.gecko.emf.osgi.annotation.provide.EPackage;

import org.osgi.annotation.versioning.ProviderType;

/**
 * <!-- begin-user-doc -->
 * The <b>Package</b> for the model.
 * It contains accessors for the meta objects to represent
 * <ul>
 *   <li>each class,</li>
 *   <li>each feature of each class,</li>
 *   <li>each operation of each class,</li>
 *   <li>each enum,</li>
 *   <li>and each data type</li>
 * </ul>
 * <!-- end-user-doc -->
 * @see org.eclipse.sensinact.model.core.provider.ProviderFactory
 * @model kind="package"
 *        annotation="http://www.eclipse.org/OCL/Import ecore='http://www.eclipse.org/emf/2002/Ecore'"
 * @generated
 */
@ProviderType
@EPackage(uri = ProviderPackage.eNS_URI, genModel = "/model/sensinact.genmodel", genModelSourceLocations = {"src/main/resources/model/sensinact.genmodel","provider/src/main/resources/model/sensinact.genmodel"}, ecore="/model/sensinact.ecore", ecoreSourceLocations="/src/main/resources/model/sensinact.ecore")
public interface ProviderPackage extends org.eclipse.emf.ecore.EPackage {
	/**
	 * The package name.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	String eNAME = "provider";

	/**
	 * The package namespace URI.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	String eNS_URI = "https://eclipse.org/sensinact/core/provider/1.0";

	/**
	 * The package namespace name.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	String eNS_PREFIX = "sensinactProvider";

	/**
	 * The singleton instance of the package.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	ProviderPackage eINSTANCE = org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl.init();

	/**
	 * The meta object id for the '{@link org.eclipse.sensinact.model.core.provider.impl.ProviderImpl <em>Provider</em>}' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderImpl
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getProvider()
	 * @generated
	 */
	int PROVIDER = 0;

	/**
	 * The feature id for the '<em><b>Id</b></em>' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int PROVIDER__ID = 0;

	/**
	 * The feature id for the '<em><b>Admin</b></em>' containment reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int PROVIDER__ADMIN = 1;

	/**
	 * The feature id for the '<em><b>Linked Providers</b></em>' reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int PROVIDER__LINKED_PROVIDERS = 2;

	/**
	 * The number of structural features of the '<em>Provider</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int PROVIDER_FEATURE_COUNT = 3;

	/**
	 * The operation id for the '<em>Get Service</em>' operation.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int PROVIDER___GET_SERVICE__STRING = 0;

	/**
	 * The operation id for the '<em>Get Service EClass</em>' operation.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int PROVIDER___GET_SERVICE_ECLASS__STRING = 1;

	/**
	 * The number of operations of the '<em>Provider</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int PROVIDER_OPERATION_COUNT = 2;

	/**
	 * The meta object id for the '{@link org.eclipse.sensinact.model.core.provider.impl.ServiceImpl <em>Service</em>}' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.sensinact.model.core.provider.impl.ServiceImpl
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getService()
	 * @generated
	 */
	int SERVICE = 2;

	/**
	 * The feature id for the '<em><b>Metadata</b></em>' map.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int SERVICE__METADATA = 0;

	/**
	 * The number of structural features of the '<em>Service</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int SERVICE_FEATURE_COUNT = 1;

	/**
	 * The operation id for the '<em>EIs Set</em>' operation.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int SERVICE___EIS_SET__ESTRUCTURALFEATURE = 0;

	/**
	 * The number of operations of the '<em>Service</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int SERVICE_OPERATION_COUNT = 1;

	/**
	 * The meta object id for the '{@link org.eclipse.sensinact.model.core.provider.impl.AdminImpl <em>Admin</em>}' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.sensinact.model.core.provider.impl.AdminImpl
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getAdmin()
	 * @generated
	 */
	int ADMIN = 1;

	/**
	 * The feature id for the '<em><b>Metadata</b></em>' map.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADMIN__METADATA = SERVICE__METADATA;

	/**
	 * The feature id for the '<em><b>Friendly Name</b></em>' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADMIN__FRIENDLY_NAME = SERVICE_FEATURE_COUNT + 0;

	/**
	 * The feature id for the '<em><b>Location</b></em>' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADMIN__LOCATION = SERVICE_FEATURE_COUNT + 1;

	/**
	 * The feature id for the '<em><b>Model Package Uri</b></em>' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADMIN__MODEL_PACKAGE_URI = SERVICE_FEATURE_COUNT + 2;

	/**
	 * The feature id for the '<em><b>Model</b></em>' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADMIN__MODEL = SERVICE_FEATURE_COUNT + 3;

	/**
	 * The number of structural features of the '<em>Admin</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADMIN_FEATURE_COUNT = SERVICE_FEATURE_COUNT + 4;

	/**
	 * The operation id for the '<em>EIs Set</em>' operation.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADMIN___EIS_SET__ESTRUCTURALFEATURE = SERVICE___EIS_SET__ESTRUCTURALFEATURE;

	/**
	 * The number of operations of the '<em>Admin</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int ADMIN_OPERATION_COUNT = SERVICE_OPERATION_COUNT + 0;

	/**
	 * The meta object id for the '{@link org.eclipse.sensinact.model.core.provider.impl.MetadataImpl <em>Metadata</em>}' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.sensinact.model.core.provider.impl.MetadataImpl
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getMetadata()
	 * @generated
	 */
	int METADATA = 3;

	/**
	 * The feature id for the '<em><b>Extra</b></em>' containment reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int METADATA__EXTRA = 0;

	/**
	 * The feature id for the '<em><b>Timestamp</b></em>' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int METADATA__TIMESTAMP = 1;

	/**
	 * The number of structural features of the '<em>Metadata</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int METADATA_FEATURE_COUNT = 2;

	/**
	 * The number of operations of the '<em>Metadata</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int METADATA_OPERATION_COUNT = 0;

	/**
	 * The meta object id for the '{@link org.eclipse.sensinact.model.core.provider.impl.FeatureMetadataImpl <em>Feature Metadata</em>}' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.sensinact.model.core.provider.impl.FeatureMetadataImpl
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getFeatureMetadata()
	 * @generated
	 */
	int FEATURE_METADATA = 4;

	/**
	 * The feature id for the '<em><b>Key</b></em>' reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int FEATURE_METADATA__KEY = 0;

	/**
	 * The feature id for the '<em><b>Value</b></em>' containment reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int FEATURE_METADATA__VALUE = 1;

	/**
	 * The number of structural features of the '<em>Feature Metadata</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int FEATURE_METADATA_FEATURE_COUNT = 2;

	/**
	 * The number of operations of the '<em>Feature Metadata</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int FEATURE_METADATA_OPERATION_COUNT = 0;

	/**
	 * The meta object id for the '{@link org.eclipse.sensinact.model.core.provider.impl.FeatureCustomMetadataImpl <em>Feature Custom Metadata</em>}' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.sensinact.model.core.provider.impl.FeatureCustomMetadataImpl
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getFeatureCustomMetadata()
	 * @generated
	 */
	int FEATURE_CUSTOM_METADATA = 5;

	/**
	 * The feature id for the '<em><b>Name</b></em>' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int FEATURE_CUSTOM_METADATA__NAME = 0;

	/**
	 * The feature id for the '<em><b>Value</b></em>' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int FEATURE_CUSTOM_METADATA__VALUE = 1;

	/**
	 * The feature id for the '<em><b>Timestamp</b></em>' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int FEATURE_CUSTOM_METADATA__TIMESTAMP = 2;

	/**
	 * The number of structural features of the '<em>Feature Custom Metadata</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int FEATURE_CUSTOM_METADATA_FEATURE_COUNT = 3;

	/**
	 * The number of operations of the '<em>Feature Custom Metadata</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int FEATURE_CUSTOM_METADATA_OPERATION_COUNT = 0;

	/**
	 * The meta object id for the '{@link org.eclipse.sensinact.model.core.provider.impl.ServiceMapImpl <em>Service Map</em>}' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.sensinact.model.core.provider.impl.ServiceMapImpl
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getServiceMap()
	 * @generated
	 */
	int SERVICE_MAP = 6;

	/**
	 * The feature id for the '<em><b>Value</b></em>' containment reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int SERVICE_MAP__VALUE = 0;

	/**
	 * The feature id for the '<em><b>Key</b></em>' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int SERVICE_MAP__KEY = 1;

	/**
	 * The number of structural features of the '<em>Service Map</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int SERVICE_MAP_FEATURE_COUNT = 2;

	/**
	 * The number of operations of the '<em>Service Map</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int SERVICE_MAP_OPERATION_COUNT = 0;

	/**
	 * The meta object id for the '{@link org.eclipse.sensinact.model.core.provider.impl.DynamicProviderImpl <em>Dynamic Provider</em>}' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.sensinact.model.core.provider.impl.DynamicProviderImpl
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getDynamicProvider()
	 * @generated
	 */
	int DYNAMIC_PROVIDER = 7;

	/**
	 * The feature id for the '<em><b>Id</b></em>' attribute.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DYNAMIC_PROVIDER__ID = PROVIDER__ID;

	/**
	 * The feature id for the '<em><b>Admin</b></em>' containment reference.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DYNAMIC_PROVIDER__ADMIN = PROVIDER__ADMIN;

	/**
	 * The feature id for the '<em><b>Linked Providers</b></em>' reference list.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DYNAMIC_PROVIDER__LINKED_PROVIDERS = PROVIDER__LINKED_PROVIDERS;

	/**
	 * The feature id for the '<em><b>Services</b></em>' map.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DYNAMIC_PROVIDER__SERVICES = PROVIDER_FEATURE_COUNT + 0;

	/**
	 * The number of structural features of the '<em>Dynamic Provider</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DYNAMIC_PROVIDER_FEATURE_COUNT = PROVIDER_FEATURE_COUNT + 1;

	/**
	 * The operation id for the '<em>Get Service</em>' operation.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DYNAMIC_PROVIDER___GET_SERVICE__STRING = PROVIDER_OPERATION_COUNT + 0;

	/**
	 * The operation id for the '<em>Get Service EClass</em>' operation.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DYNAMIC_PROVIDER___GET_SERVICE_ECLASS__STRING = PROVIDER_OPERATION_COUNT + 1;

	/**
	 * The number of operations of the '<em>Dynamic Provider</em>' class.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 * @ordered
	 */
	int DYNAMIC_PROVIDER_OPERATION_COUNT = PROVIDER_OPERATION_COUNT + 2;

	/**
	 * The meta object id for the '{@link org.eclipse.sensinact.model.core.provider.ResourceType <em>Resource Type</em>}' enum.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.sensinact.model.core.provider.ResourceType
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getResourceType()
	 * @generated
	 */
	int RESOURCE_TYPE = 8;

	/**
	 * The meta object id for the '{@link org.eclipse.sensinact.model.core.provider.ValueType <em>Value Type</em>}' enum.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.sensinact.model.core.provider.ValueType
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getValueType()
	 * @generated
	 */
	int VALUE_TYPE = 9;

	/**
	 * The meta object id for the '<em>EGeo Json Object</em>' data type.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see org.eclipse.sensinact.gateway.geojson.GeoJsonObject
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getEGeoJsonObject()
	 * @generated
	 */
	int EGEO_JSON_OBJECT = 10;

	/**
	 * The meta object id for the '<em>EInstant</em>' data type.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @see java.time.Instant
	 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getEInstant()
	 * @generated
	 */
	int EINSTANT = 11;


	/**
	 * Returns the meta object for class '{@link org.eclipse.sensinact.model.core.provider.Provider <em>Provider</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for class '<em>Provider</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Provider
	 * @generated
	 */
	EClass getProvider();

	/**
	 * Returns the meta object for the attribute '{@link org.eclipse.sensinact.model.core.provider.Provider#getId <em>Id</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the attribute '<em>Id</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Provider#getId()
	 * @see #getProvider()
	 * @generated
	 */
	EAttribute getProvider_Id();

	/**
	 * Returns the meta object for the containment reference '{@link org.eclipse.sensinact.model.core.provider.Provider#getAdmin <em>Admin</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the containment reference '<em>Admin</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Provider#getAdmin()
	 * @see #getProvider()
	 * @generated
	 */
	EReference getProvider_Admin();

	/**
	 * Returns the meta object for the reference list '{@link org.eclipse.sensinact.model.core.provider.Provider#getLinkedProviders <em>Linked Providers</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the reference list '<em>Linked Providers</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Provider#getLinkedProviders()
	 * @see #getProvider()
	 * @generated
	 */
	EReference getProvider_LinkedProviders();

	/**
	 * Returns the meta object for the '{@link org.eclipse.sensinact.model.core.provider.Provider#getService(java.lang.String) <em>Get Service</em>}' operation.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the '<em>Get Service</em>' operation.
	 * @see org.eclipse.sensinact.model.core.provider.Provider#getService(java.lang.String)
	 * @generated
	 */
	EOperation getProvider__GetService__String();

	/**
	 * Returns the meta object for the '{@link org.eclipse.sensinact.model.core.provider.Provider#getServiceEClass(java.lang.String) <em>Get Service EClass</em>}' operation.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the '<em>Get Service EClass</em>' operation.
	 * @see org.eclipse.sensinact.model.core.provider.Provider#getServiceEClass(java.lang.String)
	 * @generated
	 */
	EOperation getProvider__GetServiceEClass__String();

	/**
	 * Returns the meta object for class '{@link org.eclipse.sensinact.model.core.provider.Admin <em>Admin</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for class '<em>Admin</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Admin
	 * @generated
	 */
	EClass getAdmin();

	/**
	 * Returns the meta object for the attribute '{@link org.eclipse.sensinact.model.core.provider.Admin#getFriendlyName <em>Friendly Name</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the attribute '<em>Friendly Name</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Admin#getFriendlyName()
	 * @see #getAdmin()
	 * @generated
	 */
	EAttribute getAdmin_FriendlyName();

	/**
	 * Returns the meta object for the attribute '{@link org.eclipse.sensinact.model.core.provider.Admin#getLocation <em>Location</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the attribute '<em>Location</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Admin#getLocation()
	 * @see #getAdmin()
	 * @generated
	 */
	EAttribute getAdmin_Location();

	/**
	 * Returns the meta object for the attribute '{@link org.eclipse.sensinact.model.core.provider.Admin#getModelPackageUri <em>Model Package Uri</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the attribute '<em>Model Package Uri</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Admin#getModelPackageUri()
	 * @see #getAdmin()
	 * @generated
	 */
	EAttribute getAdmin_ModelPackageUri();

	/**
	 * Returns the meta object for the attribute '{@link org.eclipse.sensinact.model.core.provider.Admin#getModel <em>Model</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the attribute '<em>Model</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Admin#getModel()
	 * @see #getAdmin()
	 * @generated
	 */
	EAttribute getAdmin_Model();

	/**
	 * Returns the meta object for class '{@link org.eclipse.sensinact.model.core.provider.Service <em>Service</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for class '<em>Service</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Service
	 * @generated
	 */
	EClass getService();

	/**
	 * Returns the meta object for the map '{@link org.eclipse.sensinact.model.core.provider.Service#getMetadata <em>Metadata</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the map '<em>Metadata</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Service#getMetadata()
	 * @see #getService()
	 * @generated
	 */
	EReference getService_Metadata();

	/**
	 * Returns the meta object for the '{@link org.eclipse.sensinact.model.core.provider.Service#eIsSet(org.eclipse.emf.ecore.EStructuralFeature) <em>EIs Set</em>}' operation.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the '<em>EIs Set</em>' operation.
	 * @see org.eclipse.sensinact.model.core.provider.Service#eIsSet(org.eclipse.emf.ecore.EStructuralFeature)
	 * @generated
	 */
	EOperation getService__EIsSet__EStructuralFeature();

	/**
	 * Returns the meta object for class '{@link org.eclipse.sensinact.model.core.provider.Metadata <em>Metadata</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for class '<em>Metadata</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Metadata
	 * @generated
	 */
	EClass getMetadata();

	/**
	 * Returns the meta object for the containment reference list '{@link org.eclipse.sensinact.model.core.provider.Metadata#getExtra <em>Extra</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the containment reference list '<em>Extra</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Metadata#getExtra()
	 * @see #getMetadata()
	 * @generated
	 */
	EReference getMetadata_Extra();

	/**
	 * Returns the meta object for the attribute '{@link org.eclipse.sensinact.model.core.provider.Metadata#getTimestamp <em>Timestamp</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the attribute '<em>Timestamp</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.Metadata#getTimestamp()
	 * @see #getMetadata()
	 * @generated
	 */
	EAttribute getMetadata_Timestamp();

	/**
	 * Returns the meta object for class '{@link java.util.Map.Entry <em>Feature Metadata</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for class '<em>Feature Metadata</em>'.
	 * @see java.util.Map.Entry
	 * @model keyType="org.eclipse.emf.ecore.ETypedElement"
	 *        valueType="org.eclipse.sensinact.model.core.provider.Metadata" valueContainment="true"
	 * @generated
	 */
	EClass getFeatureMetadata();

	/**
	 * Returns the meta object for the reference '{@link java.util.Map.Entry <em>Key</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the reference '<em>Key</em>'.
	 * @see java.util.Map.Entry
	 * @see #getFeatureMetadata()
	 * @generated
	 */
	EReference getFeatureMetadata_Key();

	/**
	 * Returns the meta object for the containment reference '{@link java.util.Map.Entry <em>Value</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the containment reference '<em>Value</em>'.
	 * @see java.util.Map.Entry
	 * @see #getFeatureMetadata()
	 * @generated
	 */
	EReference getFeatureMetadata_Value();

	/**
	 * Returns the meta object for class '{@link org.eclipse.sensinact.model.core.provider.FeatureCustomMetadata <em>Feature Custom Metadata</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for class '<em>Feature Custom Metadata</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.FeatureCustomMetadata
	 * @generated
	 */
	EClass getFeatureCustomMetadata();

	/**
	 * Returns the meta object for the attribute '{@link org.eclipse.sensinact.model.core.provider.FeatureCustomMetadata#getName <em>Name</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the attribute '<em>Name</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.FeatureCustomMetadata#getName()
	 * @see #getFeatureCustomMetadata()
	 * @generated
	 */
	EAttribute getFeatureCustomMetadata_Name();

	/**
	 * Returns the meta object for the attribute '{@link org.eclipse.sensinact.model.core.provider.FeatureCustomMetadata#getValue <em>Value</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the attribute '<em>Value</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.FeatureCustomMetadata#getValue()
	 * @see #getFeatureCustomMetadata()
	 * @generated
	 */
	EAttribute getFeatureCustomMetadata_Value();

	/**
	 * Returns the meta object for the attribute '{@link org.eclipse.sensinact.model.core.provider.FeatureCustomMetadata#getTimestamp <em>Timestamp</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the attribute '<em>Timestamp</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.FeatureCustomMetadata#getTimestamp()
	 * @see #getFeatureCustomMetadata()
	 * @generated
	 */
	EAttribute getFeatureCustomMetadata_Timestamp();

	/**
	 * Returns the meta object for class '{@link java.util.Map.Entry <em>Service Map</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for class '<em>Service Map</em>'.
	 * @see java.util.Map.Entry
	 * @model features="value key" 
	 *        valueType="org.eclipse.sensinact.model.core.provider.Service" valueContainment="true"
	 *        keyDataType="org.eclipse.emf.ecore.EString"
	 * @generated
	 */
	EClass getServiceMap();

	/**
	 * Returns the meta object for the containment reference '{@link java.util.Map.Entry <em>Value</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the containment reference '<em>Value</em>'.
	 * @see java.util.Map.Entry
	 * @see #getServiceMap()
	 * @generated
	 */
	EReference getServiceMap_Value();

	/**
	 * Returns the meta object for the attribute '{@link java.util.Map.Entry <em>Key</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the attribute '<em>Key</em>'.
	 * @see java.util.Map.Entry
	 * @see #getServiceMap()
	 * @generated
	 */
	EAttribute getServiceMap_Key();

	/**
	 * Returns the meta object for class '{@link org.eclipse.sensinact.model.core.provider.DynamicProvider <em>Dynamic Provider</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for class '<em>Dynamic Provider</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.DynamicProvider
	 * @generated
	 */
	EClass getDynamicProvider();

	/**
	 * Returns the meta object for the map '{@link org.eclipse.sensinact.model.core.provider.DynamicProvider#getServices <em>Services</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the map '<em>Services</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.DynamicProvider#getServices()
	 * @see #getDynamicProvider()
	 * @generated
	 */
	EReference getDynamicProvider_Services();

	/**
	 * Returns the meta object for the '{@link org.eclipse.sensinact.model.core.provider.DynamicProvider#getService(java.lang.String) <em>Get Service</em>}' operation.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the '<em>Get Service</em>' operation.
	 * @see org.eclipse.sensinact.model.core.provider.DynamicProvider#getService(java.lang.String)
	 * @generated
	 */
	EOperation getDynamicProvider__GetService__String();

	/**
	 * Returns the meta object for the '{@link org.eclipse.sensinact.model.core.provider.DynamicProvider#getServiceEClass(java.lang.String) <em>Get Service EClass</em>}' operation.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for the '<em>Get Service EClass</em>' operation.
	 * @see org.eclipse.sensinact.model.core.provider.DynamicProvider#getServiceEClass(java.lang.String)
	 * @generated
	 */
	EOperation getDynamicProvider__GetServiceEClass__String();

	/**
	 * Returns the meta object for enum '{@link org.eclipse.sensinact.model.core.provider.ResourceType <em>Resource Type</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for enum '<em>Resource Type</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.ResourceType
	 * @generated
	 */
	EEnum getResourceType();

	/**
	 * Returns the meta object for enum '{@link org.eclipse.sensinact.model.core.provider.ValueType <em>Value Type</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for enum '<em>Value Type</em>'.
	 * @see org.eclipse.sensinact.model.core.provider.ValueType
	 * @generated
	 */
	EEnum getValueType();

	/**
	 * Returns the meta object for data type '{@link org.eclipse.sensinact.gateway.geojson.GeoJsonObject <em>EGeo Json Object</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for data type '<em>EGeo Json Object</em>'.
	 * @see org.eclipse.sensinact.gateway.geojson.GeoJsonObject
	 * @model instanceClass="org.eclipse.sensinact.gateway.geojson.GeoJsonObject"
	 * @generated
	 */
	EDataType getEGeoJsonObject();

	/**
	 * Returns the meta object for data type '{@link java.time.Instant <em>EInstant</em>}'.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the meta object for data type '<em>EInstant</em>'.
	 * @see java.time.Instant
	 * @model instanceClass="java.time.Instant"
	 * @generated
	 */
	EDataType getEInstant();

	/**
	 * Returns the factory that creates the instances of the model.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the factory that creates the instances of the model.
	 * @generated
	 */
	ProviderFactory getProviderFactory();

	/**
	 * <!-- begin-user-doc -->
	 * Defines literals for the meta objects that represent
	 * <ul>
	 *   <li>each class,</li>
	 *   <li>each feature of each class,</li>
	 *   <li>each operation of each class,</li>
	 *   <li>each enum,</li>
	 *   <li>and each data type</li>
	 * </ul>
	 * <!-- end-user-doc -->
	 * @generated
	 */
	interface Literals {
		/**
		 * The meta object literal for the '{@link org.eclipse.sensinact.model.core.provider.impl.ProviderImpl <em>Provider</em>}' class.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderImpl
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getProvider()
		 * @generated
		 */
		EClass PROVIDER = eINSTANCE.getProvider();

		/**
		 * The meta object literal for the '<em><b>Id</b></em>' attribute feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EAttribute PROVIDER__ID = eINSTANCE.getProvider_Id();

		/**
		 * The meta object literal for the '<em><b>Admin</b></em>' containment reference feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EReference PROVIDER__ADMIN = eINSTANCE.getProvider_Admin();

		/**
		 * The meta object literal for the '<em><b>Linked Providers</b></em>' reference list feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EReference PROVIDER__LINKED_PROVIDERS = eINSTANCE.getProvider_LinkedProviders();

		/**
		 * The meta object literal for the '<em><b>Get Service</b></em>' operation.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EOperation PROVIDER___GET_SERVICE__STRING = eINSTANCE.getProvider__GetService__String();

		/**
		 * The meta object literal for the '<em><b>Get Service EClass</b></em>' operation.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EOperation PROVIDER___GET_SERVICE_ECLASS__STRING = eINSTANCE.getProvider__GetServiceEClass__String();

		/**
		 * The meta object literal for the '{@link org.eclipse.sensinact.model.core.provider.impl.AdminImpl <em>Admin</em>}' class.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @see org.eclipse.sensinact.model.core.provider.impl.AdminImpl
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getAdmin()
		 * @generated
		 */
		EClass ADMIN = eINSTANCE.getAdmin();

		/**
		 * The meta object literal for the '<em><b>Friendly Name</b></em>' attribute feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EAttribute ADMIN__FRIENDLY_NAME = eINSTANCE.getAdmin_FriendlyName();

		/**
		 * The meta object literal for the '<em><b>Location</b></em>' attribute feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EAttribute ADMIN__LOCATION = eINSTANCE.getAdmin_Location();

		/**
		 * The meta object literal for the '<em><b>Model Package Uri</b></em>' attribute feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EAttribute ADMIN__MODEL_PACKAGE_URI = eINSTANCE.getAdmin_ModelPackageUri();

		/**
		 * The meta object literal for the '<em><b>Model</b></em>' attribute feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EAttribute ADMIN__MODEL = eINSTANCE.getAdmin_Model();

		/**
		 * The meta object literal for the '{@link org.eclipse.sensinact.model.core.provider.impl.ServiceImpl <em>Service</em>}' class.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @see org.eclipse.sensinact.model.core.provider.impl.ServiceImpl
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getService()
		 * @generated
		 */
		EClass SERVICE = eINSTANCE.getService();

		/**
		 * The meta object literal for the '<em><b>Metadata</b></em>' map feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EReference SERVICE__METADATA = eINSTANCE.getService_Metadata();

		/**
		 * The meta object literal for the '<em><b>EIs Set</b></em>' operation.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EOperation SERVICE___EIS_SET__ESTRUCTURALFEATURE = eINSTANCE.getService__EIsSet__EStructuralFeature();

		/**
		 * The meta object literal for the '{@link org.eclipse.sensinact.model.core.provider.impl.MetadataImpl <em>Metadata</em>}' class.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @see org.eclipse.sensinact.model.core.provider.impl.MetadataImpl
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getMetadata()
		 * @generated
		 */
		EClass METADATA = eINSTANCE.getMetadata();

		/**
		 * The meta object literal for the '<em><b>Extra</b></em>' containment reference list feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EReference METADATA__EXTRA = eINSTANCE.getMetadata_Extra();

		/**
		 * The meta object literal for the '<em><b>Timestamp</b></em>' attribute feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EAttribute METADATA__TIMESTAMP = eINSTANCE.getMetadata_Timestamp();

		/**
		 * The meta object literal for the '{@link org.eclipse.sensinact.model.core.provider.impl.FeatureMetadataImpl <em>Feature Metadata</em>}' class.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @see org.eclipse.sensinact.model.core.provider.impl.FeatureMetadataImpl
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getFeatureMetadata()
		 * @generated
		 */
		EClass FEATURE_METADATA = eINSTANCE.getFeatureMetadata();

		/**
		 * The meta object literal for the '<em><b>Key</b></em>' reference feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EReference FEATURE_METADATA__KEY = eINSTANCE.getFeatureMetadata_Key();

		/**
		 * The meta object literal for the '<em><b>Value</b></em>' containment reference feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EReference FEATURE_METADATA__VALUE = eINSTANCE.getFeatureMetadata_Value();

		/**
		 * The meta object literal for the '{@link org.eclipse.sensinact.model.core.provider.impl.FeatureCustomMetadataImpl <em>Feature Custom Metadata</em>}' class.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @see org.eclipse.sensinact.model.core.provider.impl.FeatureCustomMetadataImpl
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getFeatureCustomMetadata()
		 * @generated
		 */
		EClass FEATURE_CUSTOM_METADATA = eINSTANCE.getFeatureCustomMetadata();

		/**
		 * The meta object literal for the '<em><b>Name</b></em>' attribute feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EAttribute FEATURE_CUSTOM_METADATA__NAME = eINSTANCE.getFeatureCustomMetadata_Name();

		/**
		 * The meta object literal for the '<em><b>Value</b></em>' attribute feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EAttribute FEATURE_CUSTOM_METADATA__VALUE = eINSTANCE.getFeatureCustomMetadata_Value();

		/**
		 * The meta object literal for the '<em><b>Timestamp</b></em>' attribute feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EAttribute FEATURE_CUSTOM_METADATA__TIMESTAMP = eINSTANCE.getFeatureCustomMetadata_Timestamp();

		/**
		 * The meta object literal for the '{@link org.eclipse.sensinact.model.core.provider.impl.ServiceMapImpl <em>Service Map</em>}' class.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @see org.eclipse.sensinact.model.core.provider.impl.ServiceMapImpl
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getServiceMap()
		 * @generated
		 */
		EClass SERVICE_MAP = eINSTANCE.getServiceMap();

		/**
		 * The meta object literal for the '<em><b>Value</b></em>' containment reference feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EReference SERVICE_MAP__VALUE = eINSTANCE.getServiceMap_Value();

		/**
		 * The meta object literal for the '<em><b>Key</b></em>' attribute feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EAttribute SERVICE_MAP__KEY = eINSTANCE.getServiceMap_Key();

		/**
		 * The meta object literal for the '{@link org.eclipse.sensinact.model.core.provider.impl.DynamicProviderImpl <em>Dynamic Provider</em>}' class.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @see org.eclipse.sensinact.model.core.provider.impl.DynamicProviderImpl
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getDynamicProvider()
		 * @generated
		 */
		EClass DYNAMIC_PROVIDER = eINSTANCE.getDynamicProvider();

		/**
		 * The meta object literal for the '<em><b>Services</b></em>' map feature.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EReference DYNAMIC_PROVIDER__SERVICES = eINSTANCE.getDynamicProvider_Services();

		/**
		 * The meta object literal for the '<em><b>Get Service</b></em>' operation.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EOperation DYNAMIC_PROVIDER___GET_SERVICE__STRING = eINSTANCE.getDynamicProvider__GetService__String();

		/**
		 * The meta object literal for the '<em><b>Get Service EClass</b></em>' operation.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @generated
		 */
		EOperation DYNAMIC_PROVIDER___GET_SERVICE_ECLASS__STRING = eINSTANCE.getDynamicProvider__GetServiceEClass__String();

		/**
		 * The meta object literal for the '{@link org.eclipse.sensinact.model.core.provider.ResourceType <em>Resource Type</em>}' enum.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @see org.eclipse.sensinact.model.core.provider.ResourceType
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getResourceType()
		 * @generated
		 */
		EEnum RESOURCE_TYPE = eINSTANCE.getResourceType();

		/**
		 * The meta object literal for the '{@link org.eclipse.sensinact.model.core.provider.ValueType <em>Value Type</em>}' enum.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @see org.eclipse.sensinact.model.core.provider.ValueType
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getValueType()
		 * @generated
		 */
		EEnum VALUE_TYPE = eINSTANCE.getValueType();

		/**
		 * The meta object literal for the '<em>EGeo Json Object</em>' data type.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @see org.eclipse.sensinact.gateway.geojson.GeoJsonObject
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getEGeoJsonObject()
		 * @generated
		 */
		EDataType EGEO_JSON_OBJECT = eINSTANCE.getEGeoJsonObject();

		/**
		 * The meta object literal for the '<em>EInstant</em>' data type.
		 * <!-- begin-user-doc -->
		 * <!-- end-user-doc -->
		 * @see java.time.Instant
		 * @see org.eclipse.sensinact.model.core.provider.impl.ProviderPackageImpl#getEInstant()
		 * @generated
		 */
		EDataType EINSTANT = eINSTANCE.getEInstant();

	}

} //ProviderPackage
